@@ -4,7 +4,7 @@
  * Start Date:  Wed Nov 29 22:04:49 1995
  * Project:     INN (innfeed)
  * File:        endpoint.h
- * RCSId:       $Id: endpoint.h,v 1.8 1997/03/03 12:48:25 brister Exp $
+ * RCSId:       $Id: endpoint.h,v 1.3 1997/04/30 23:57:23 scrappy Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -74,9 +74,13 @@
  *      typedef enum {
  *          IoDone,                     i/o completed successfully 
  *          IoIncomplete,               i/o still got more to read/write
+ *          IoProgress,                 i/o still got more to read/write
  *          IoFailed                    i/o failed
  *      } IoStatus ;
  *
+ * The completion callbacks are never called with the status IoIncomplete or
+ * IoProgress.
+ *
  *****************************************
  *
  * typedef for function callback when IO is complete (or failed).
@@ -124,13 +128,17 @@ int prepareRead (EndPoint endp,
 /* Request a write when possible. All the data in the buffers in
  * BUFFS will be written out the endpoint. BUFFS is a NULL
  * terminated array of Buffers. See prepareWrite for a discussion on
- * the ownership of BUFFS and the Buffers inside BUFFS. The CALLBACK
- * function will be called and the CLIENTDATA value will be passed
- * through to it. Returns non-zero if scheduled succesfully.
+ * the ownership of BUFFS and the Buffers inside BUFFS. The PROGRESS
+ * callback function will be called and the CLIENTDATA value will be
+ * passed through to it whenever any data is written except for the
+ * final write.  The DONE callback function will be called and the
+ * CLIENTDATA value will be passed through to it after the final write.
+ * Returns non-zero if scheduled succesfully.
  */
 int prepareWrite (EndPoint endp,
                   Buffer *buffs,
-                  EndpRWCB func,
+                  EndpRWCB progress,
+                  EndpRWCB done,
                   void *clientData) ;
 
 /* cancel any outstanding reads. */
@@ -155,6 +163,12 @@ TimeoutId prepareSleep (EndpTCB func,
                         int timeToSleep,
                         void *clientData) ;
 
+/* Updates tid to wakeup TIMETOSLEEP seconds from now. */
+TimeoutId updateSleep (TimeoutId tid,
+                       EndpTCB func,
+                       int timeToSleep,
+                       void *clientData) ;
+
   /* Set up a function to be called whenever the endpoint's file descriptor
      is NOT ready. This is called after all other fd-ready endpoints have
      been serviced. */
@@ -181,6 +195,9 @@ int endPointErrno (EndPoint endp) ;
    considered first for servicing (i.e. the EndPoint connectied to innd) */
 void setMainEndPoint (EndPoint endp) ;
 
+/* returns the fd of the main endpoint */
+int getMainEndPointFd (void) ;
+
 void freeTimeoutQueue (void) ;
 
 int endpointConfigLoadCbk (void *data) ;
