@@ -4,7 +4,7 @@
  * Start Date:  Mon, 15 Jan 1996 17:31:58 +1100
  * Project:     INN -- innfeed
  * File:        main.c
- * RCSId:       $Id: main.c,v 1.25 1997/03/03 13:06:35 brister Exp $
+ * RCSId:       $Id: main.c,v 1.5 1997/08/25 05:32:37 scrappy Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -29,7 +29,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: main.c,v 1.25 1997/03/03 13:06:35 brister Exp $" ;
+static const char *rcsid = "$Id: main.c,v 1.5 1997/08/25 05:32:37 scrappy Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -80,6 +80,12 @@ static void use_rcsid (const char *rid) {   /* Never called */
 #include "host.h"
 #include "innlistener.h"
 
+#ifdef  XXX_RAWHACK
+#include <configdata.h>
+#include "raw.h"
+char *LogName = "innfeed";
+#endif  /* XXX_RAWHACK */
+
 #define INHERIT 1
 #define NO_INHERIT 0
 
@@ -107,7 +113,7 @@ extern void openInputFile (void);
 static char *logFile ;
 static char *newsspool ;
 
-static void sigiot (int sig) ;
+static void sigemt (int sig) ;
 static void sigalrm (int sig) ;
 static void sigchld (int sig) ;
 static void sigint (int sig) ;
@@ -167,9 +173,13 @@ int main (int argc, char **argv)
   useMMap = false ;
 #endif
 
+#ifdef	XXX_RAWHACK_CRLFSTORAGE
+  artBitFiddleContents (false) ;
+#else	/* XXX_RAWHACK_CRLFSTORAGE */
   /* always turn on copying into memory unless mmapping and the article
      data being in NNTP format. */
   artBitFiddleContents (true) ;
+#endif	/* XXX_RAWHACK_CRLFSTORAGE */
 
 #define OPT_STRING "a:b:c:Cd:e:hl:mMo:p:S:s:vxyz"
 
@@ -318,6 +328,11 @@ int main (int argc, char **argv)
       syslog (LOG_NOTICE,STARTING_PROGRAM,versionInfo,dateString) ;
     }
 
+#ifdef  XXX_RAWHACK
+  syslog(LOG_NOTICE, "Calling RAWread_config()");
+  RAWread_config();
+#endif  /* XXX_RAWHACK */
+
   if (subProgram == NULL && talkToSelf == false)
     {
       struct stat buf ;
@@ -328,13 +343,6 @@ int main (int argc, char **argv)
         InputFile = "";
     }
 
-  if (subProgram != NULL && (talkToSelf == true || InputFile))
-    {
-      dprintf (0,"Cannot specify '-s' with '-x' or an input file\n") ;
-      syslog (LOG_ERR,"Incorrect arguments: '-s' with '-x' or an input file\n");
-      usage (1) ;
-    }
-
   /*
    * set up the config file name and then read the file in. Order is important.
    */
@@ -364,6 +372,14 @@ int main (int argc, char **argv)
 
   rval = readConfig (configFile,(checkConfig ? stderr : NULL),
                      checkConfig,loggingLevel > 0);
+
+  if (subProgram != NULL && (talkToSelf == true || InputFile))
+    {
+      dprintf (0,"Cannot specify '-s' with '-x' or an input file\n") ;
+      syslog (LOG_ERR,"Incorrect arguments: '-s' with '-x' or an input file\n");
+      usage (1) ;
+    }
+
   if (checkConfig)
     {
       if (!rval)
@@ -506,7 +522,7 @@ int main (int argc, char **argv)
   setSigHandler (SIGALRM,sigalrm) ;
 
   /* handle signal to flush all the backlog files */
-  setSigHandler (SIGIOT,sigiot) ;
+  setSigHandler (SIGEMT,sigemt) ;
 
   /* we can increment and decrement logging levels by sending SIGUSR{1,2} */
   setSigHandler (SIGUSR1,sigusr) ;
@@ -621,7 +637,7 @@ static void sighup (int sig)
   configHosts (talkToSelf) ;
 }
 
-static void sigiot (int sig)
+static void sigemt (int sig)
 {
   (void) sig ;
 
@@ -781,6 +797,15 @@ static int mainConfigLoadCbk (void *data)
 
   /***************************************************/
   
+  if (getString (topScope,"input-file",&p,NO_INHERIT))
+    {
+      if (*p != '\0')
+	InputFile = buildFilename (getTapeDirectory(),p) ;
+      else
+	InputFile = "" ;
+      free (p) ;
+    }
+  
   if (getString (topScope,"pid-file",&p,NO_INHERIT))
     {
       pidFile = buildFilename (getTapeDirectory(),p) ;
@@ -873,7 +898,7 @@ static int mainOptionsProcess (void *data)
       if ((v = findValue (topScope,"backlog-limit",NO_INHERIT)) != NULL)
         v->v.int_val = elimit ;
       else
-        addInteger (topScope,"backlog-limit",debugLevel) ;
+        addInteger (topScope,"backlog-limit",elimit) ;
     }
 
   
@@ -916,6 +941,17 @@ static int mainOptionsProcess (void *data)
         addString (topScope,"log-file",strdup (lopt)) ;
     }
 
+  if (InputFile != NULL)
+    {
+      if ((v = findValue (topScope,"input-file",NO_INHERIT)) != NULL)
+        {
+          FREE (v->v.charp_val) ;
+          v->v.charp_val = strdup (InputFile) ;
+        }
+      else
+        addString (topScope,"input-file",strdup (InputFile)) ;
+    }
+
   return 1 ;
 }
 
