@@ -1,4 +1,4 @@
-/* $Revision: 1.3 $
+/* $Revision: 1.2 $
  *
  * Revision 4.0.1.1  91/04/11  17:48:31  lwall
  * patch1: Configure now figures out malloc ptr type
@@ -407,4 +407,17 @@ mstats(s)
 	    totused, totfree);
 }
 #endif
+
+POINTER
+calloc(num, size)
+	SIZE_T num;
+	register SIZE_T size;
+{
+	register void *p;
+
+	size *= num;
+	if (p = malloc(size))
+		memset(p, 0, size);
+	return(p);
+}
 #endif /* lint */
