@@ -4,7 +4,7 @@
  * Start Date:  Thu, 01 Feb 1996 22:17:51 +1100
  * Project:     INN -- innfeed
  * File:        sysconfig.h
- * RCSId:       $Id: sysconfig.h,v 1.13 1997/03/03 13:21:15 brister Exp $
+ * RCSId:       $Id: sysconfig.h,v 1.5 1997/08/25 05:32:40 scrappy Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -83,7 +83,10 @@
 /* Note: If you are running version 5.4.3 or better of libc, then 16 is the
    number to use. Lower than that, and you should use 1. */
 #define MAX_WRITEV_VEC 1
-#define DO_NEED_SYS_SELECT 1
+#undef DO_NEED_SYS_SELECT 
+#define HAVE_MMAP 1
+#define NBIO_FCNTL 1
+#define USE_SIGACTION
 #endif
 
 
@@ -126,6 +129,7 @@
 #define DO_NEED_STRERROR 1
 #define HAVE_MMAP
 #define MAX_STDIO_FD 128
+#define atexit(arg) on_exit (arg,0)
 #endif
 
 
@@ -176,6 +180,10 @@
 #define _BSD 44
 #endif
 
+#if ! defined (USE_SIGSET) && ! defined(USE_SIGVEC)
+#define USE_SIGACTION
+#endif
+
 
 
   /* Defaults below here. If you need to change something it should really
@@ -255,6 +263,9 @@
 #define GETSOCKOPT_ARG void *
 #endif
 
+#if ! defined (USE_SIGSET) && ! defined(USE_SIGVEC)
+#define USE_SIGACTION
+#endif
 
 
 /***************************************************************************
